package com.example.api.core.data.core

import com.example.api.core.domain.ApiRepository
import com.jakewharton.retrofit2.converter.kotlinx.serialization.asConverterFactory
import kotlinx.serialization.json.Json
import okhttp3.MediaType.Companion.toMediaType
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.create

/**
 * фабрика для создание инстанса интерфейса без внешнего доступа к реализации
* */
object ApiFactory {

    fun provideRepository(dataStoreRepository: DataStoreRepository): ApiRepository {
        val json = Json { ignoreUnknownKeys = true }
        val client = OkHttpClient.Builder()
            .addInterceptor(HttpLoggingInterceptor().apply {
                level = HttpLoggingInterceptor.Level.BODY
            })
            .addInterceptor(AuthInterceptor(dataStoreRepository))
            .build()

        val retrofit = Retrofit.Builder()
            .baseUrl("https://api.matule.ru/api/")
            .addConverterFactory(json.asConverterFactory("application/json".toMediaType()))
            .client(client)
            .build()


        return BaseApiRepository(retrofit.create<ApiService>(), dataStoreRepository, Handle.Base())
    }
}