package com.example.api.core.data.core

import kotlinx.coroutines.flow.first
import kotlinx.coroutines.runBlocking
import okhttp3.Interceptor
import okhttp3.Response

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

/**
 * Перехватчик для установки токена в заголовок запроса
* */
class AuthInterceptor(private val dataStoreRepository: DataStoreRepository) : Interceptor {
    override fun intercept(chain: Interceptor.Chain): Response {
        val token = runBlocking { dataStoreRepository.token().first() }
        val request = chain.request().newBuilder().apply {
            token?.let { addHeader("Authorization", "Bearer $token") }
        }

        return chain.proceed(request.build())
    }
}