package com.example.api.core.data.core

import com.example.api.core.domain.ApiRepository
import com.example.api.core.domain.AuthUserResponse
import com.example.api.core.domain.FetchResult
import com.example.api.core.domain.RegisterUser
import com.example.api.core.domain.Projects
import retrofit2.HttpException
import java.net.UnknownHostException

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

/**
 * общая структура обработки запросов
* */
internal interface Handle {
    suspend fun <T> handle(action: suspend () -> T): FetchResult<T>

    class Base : Handle {
        override suspend fun <T> handle(action: suspend () -> T): FetchResult<T> {
            return try {
                val result = action.invoke()

                FetchResult.Success(result)
            } catch (e: UnknownHostException) {
                FetchResult.Error(null, "no internet connection")
            } catch (e: HttpException) {
                FetchResult.Error(null, e.message())
            } catch (e: Exception) {
                FetchResult.Error(null, e.message!!)
            }
        }

    }
}

internal class BaseApiRepository(
    private val service: ApiService,
    private val dataStoreRepository: DataStoreRepository,
    private val handle: Handle,
) : RemoteMapper(), ApiRepository {

    override suspend fun auth(registerUser: RegisterUser): FetchResult<AuthUserResponse> = handle.handle {
        service.register(registerUser.toRegisterUserDto())
        val response = service.auth(registerUser.toSignInUserDto())
        dataStoreRepository.saveToken(response.token)
        response.toUserResponse()
    }


    override suspend fun projects(): FetchResult<Projects> = handle.handle {
        service.projects().toDomain()
    }
}