package com.example.api.core.data.core

import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

/**
 * Локальное хранение токена
* */
interface DataStoreRepository {

    suspend fun saveToken(token: String)

    fun token(): Flow<String?>

    class Base(private val preferences: DataStore<Preferences>) : DataStoreRepository {
        override suspend fun saveToken(token: String) {
            preferences.edit { settings ->
                settings[TOKEN_KEY] = token
            }
        }

        override fun token(): Flow<String?> {
            return preferences.data.map { preferences ->
                preferences[TOKEN_KEY]
            }
        }
    }

    private companion object {
        val TOKEN_KEY = stringPreferencesKey("token_key")
    }
}