package com.example.api.core.domain

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

interface FetchResult<D> {

    fun <Ui> map(mapper: Mapper<D, Ui>): Ui

    interface Mapper<D, Ui> {

        fun mapSuccess(data: D): Ui

        fun mapError(data: D?, message: String): Ui
    }

    class Success<D>(private val data: D) : FetchResult<D> {
        override fun <Ui> map(mapper: Mapper<D, Ui>): Ui {
            return mapper.mapSuccess(data)
        }
    }

    class Error<D>(private val data: D?, private val message: String) : FetchResult<D> {
        override fun <Ui> map(mapper: Mapper<D, Ui>): Ui {
            return mapper.mapError(data, message)
        }

    }
}