package com.example.api

import android.content.Context
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.preferencesDataStore
import com.example.api.core.data.core.ApiFactory
import com.example.api.core.data.core.DataStoreRepository
import com.example.api.core.domain.ApiRepository
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.android.qualifiers.ApplicationContext
import dagger.hilt.components.SingletonComponent
import javax.inject.Singleton

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

@Module
@InstallIn(SingletonComponent::class)
class CoreModule {

    @Provides
    @Singleton
    fun provideContent(@ApplicationContext context: Context): Context = context

    @Provides
    @Singleton
    fun provideDataStore(context: Context): DataStore<Preferences> {
        return context.dataStore
    }

    @Provides
    @Singleton
    fun provideDataStoreRepository(preferences: DataStore<Preferences>): DataStoreRepository {
        return DataStoreRepository.Base(preferences)
    }

    @Provides
    @Singleton
    fun provideRepository(dataStoreRepository: DataStoreRepository): ApiRepository {
        return ApiFactory.provideRepository(dataStoreRepository)
    }

    companion object {
        private val Context.dataStore by preferencesDataStore("settings")
    }
}