package com.example.api

import androidx.compose.runtime.Composable

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

interface FetchResultUiState<T> {

    @Composable
    fun Show(
        onSuccess: @Composable (T) -> Unit,
        onError: @Composable (T?, String) -> Unit,
        onLoading: @Composable (T?) -> Unit
    )

    class Success<T>(val data: T) : FetchResultUiState<T> {
        @Composable
        override fun Show(
            onSuccess: @Composable (T) -> Unit,
            onError: @Composable (T?, String) -> Unit,
            onLoading: @Composable (T?) -> Unit
        ) {
            onSuccess(data)
        }
    }

    class Error<T>(private val data: T?, private val message: String) : FetchResultUiState<T> {
        @Composable
        override fun Show(
            onSuccess: @Composable (T) -> Unit,
            onError: @Composable (T?, String) -> Unit,
            onLoading: @Composable (T?) -> Unit
        ) {
            onError(data, message)
        }

    }

    class Loading<T>(private val data: T? = null) : FetchResultUiState<T> {
        @Composable
        override fun Show(
            onSuccess: @Composable (T) -> Unit,
            onError: @Composable (T?, String) -> Unit,
            onLoading: @Composable (T?) -> Unit
        ) {
            onLoading(data)
        }
    }

    class Initial<T> : FetchResultUiState<T> {
        @Composable
        override fun Show(
            onSuccess: @Composable (T) -> Unit,
            onError: @Composable (T?, String) -> Unit,
            onLoading: @Composable (T?) -> Unit
        ) {
        }
    }
}