package com.example.api

import com.example.api.core.domain.ApiRepository
import com.example.api.core.domain.AuthUserResponse
import com.example.api.core.domain.Projects
import com.example.api.core.domain.RegisterUser
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import javax.inject.Inject

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

@HiltViewModel
class MainViewModel @Inject constructor(
    private val apiRepository: ApiRepository
) : BaseViewModel() {

    private val _authUiState =
        MutableStateFlow<FetchResultUiState<AuthUserResponse>>(FetchResultUiState.Initial())
    val authUiState: StateFlow<FetchResultUiState<AuthUserResponse>>
        get() = _authUiState.asStateFlow()

    private val _projectsUiState =
        MutableStateFlow<FetchResultUiState<Projects>>(FetchResultUiState.Initial())
    val projectsUiState: StateFlow<FetchResultUiState<Projects>>
        get() = _projectsUiState.asStateFlow()

    fun auth(email: String, password: String) {
        handle(
            action = {
                apiRepository.auth(
                    RegisterUser(
                        email = email,
                        password = password,
                        passwordConfirm = password
                    )
                )
            }
        ) {
            _authUiState.value = it.map(FetchResultMapper())
        }
    }

    fun salesAndProjects() {
        handle(
            action = { apiRepository.projects() }
        ) {
            _projectsUiState.value = it.map(FetchResultMapper())
        }
    }
}